permaculture.testing package
============================

Submodules
----------

permaculture.testing.fixtures module
------------------------------------

.. automodule:: permaculture.testing.fixtures
   :members:
   :undoc-members:
   :show-inheritance:

permaculture.testing.logger module
----------------------------------

.. automodule:: permaculture.testing.logger
   :members:
   :undoc-members:
   :show-inheritance:

permaculture.testing.unique module
----------------------------------

.. automodule:: permaculture.testing.unique
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: permaculture.testing
   :members:
   :undoc-members:
   :show-inheritance:
